==> haskell-implicit-hie-cradle-0.5.0.1-160-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-implicit-hie-cradle.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 implicit-hie-cradle
version:              0.5.0.1
visibility:           public
id:                   implicit-hie-cradle-0.5.0.1-LdhhSa8B4OJAs1oSEZzXGp
key:                  implicit-hie-cradle-0.5.0.1-LdhhSa8B4OJAs1oSEZzXGp
license:              BSD-3-Clause
copyright:            2023
maintainer:           avi.the.coder@gmail.com
author:               Avi Dessauer
homepage:             https://github.com/Avi-D-coder/implicit-hie-cradle#readme
synopsis:             Auto generate hie-bios cradles
description:          Auto generate a stack or cabal multi component cradles
category:             Development, Tools, Hie, HLS
abi:                  ff5ecdc3a379e369d228c4eb6f851787
exposed:              True
exposed-modules:      Hie.Implicit.Cradle
hidden-modules:       Paths_implicit_hie_cradle
import-dirs:          /usr/lib/ghc-9.4.8/site-local/implicit-hie-cradle-0.5.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/implicit-hie-cradle-0.5.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/implicit-hie-cradle-0.5.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-implicit-hie-cradle
hs-libraries:         HSimplicit-hie-cradle-0.5.0.1-LdhhSa8B4OJAs1oSEZzXGp
depends:
    base-4.17.2.1 directory-1.3.7.1 extra-1.7.16-KxrHBQWVwMp2M62XitBte8
    filepath-1.4.2.2 hie-bios-0.12.0-9MqyXfNlNQe4AP5ks5mD6C
    implicit-hie-0.1.4.0-4gORIw4Q5qr9jIMIe76RUm process-1.6.18.0
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-implicit-hie-cradle/html/implicit-hie-cradle.haddock

haddock-html:         /usr/share/doc/haskell-implicit-hie-cradle/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-implicit-hie-cradle-0.5.0.1-179-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-implicit-hie-cradle.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 implicit-hie-cradle
version:              0.5.0.1
visibility:           public
id:                   implicit-hie-cradle-0.5.0.1-5VYWUxWhcJ75pzT0fB628d
key:                  implicit-hie-cradle-0.5.0.1-5VYWUxWhcJ75pzT0fB628d
license:              BSD-3-Clause
copyright:            2023
maintainer:           avi.the.coder@gmail.com
author:               Avi Dessauer
homepage:             https://github.com/Avi-D-coder/implicit-hie-cradle#readme
synopsis:             Auto generate hie-bios cradles
description:          Auto generate a stack or cabal multi component cradles
category:             Development, Tools, Hie, HLS
abi:                  1de5423480884c025755486ccabfeedc
exposed:              True
exposed-modules:      Hie.Implicit.Cradle
hidden-modules:       Paths_implicit_hie_cradle
import-dirs:          /usr/lib/ghc-9.4.8/site-local/implicit-hie-cradle-0.5.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/implicit-hie-cradle-0.5.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/implicit-hie-cradle-0.5.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-implicit-hie-cradle
hs-libraries:         HSimplicit-hie-cradle-0.5.0.1-5VYWUxWhcJ75pzT0fB628d
depends:
    base-4.17.2.1 directory-1.3.7.1 extra-1.7.16-CyTEZvSfBxsKCwY9ZtJE7E
    filepath-1.4.2.2 hie-bios-0.12.0-9XHeK8HLoeP7nIXSeWEUTe
    implicit-hie-0.1.4.0-1PjgBq5GgmFHElPc0sqYLl process-1.6.18.0
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-implicit-hie-cradle/html/implicit-hie-cradle.haddock

haddock-html:         /usr/share/doc/haskell-implicit-hie-cradle/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
